'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _invariant = require('invariant');

var _invariant2 = _interopRequireDefault(_invariant);

var _Session = require('./Session');

var _Session2 = _interopRequireDefault(_Session);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

/**
 * Given a schema and set of indices, check to make sure that every property
 * key on the indices exist in the given schema.
 */
var checkForPropertyKey = function checkForPropertyKey(schema, indices) {
  var schemaPropertyKeys = schema.propertyKeys;

  var currentPropertyKeys = schemaPropertyKeys.map(function (_ref) {
    var name = _ref.name;
    return name;
  });

  var missingPropertyKeys = [];

  indices.forEach(function (index) {
    var indexPropertyKeys = index.propertyKeys;

    indexPropertyKeys.forEach(function (propertyKey) {

      if (currentPropertyKeys.indexOf(propertyKey) === -1) {
        missingPropertyKeys.push(propertyKey);
      }
    });
  });

  (0, _invariant2.default)(missingPropertyKeys.length === 0, 'You are trying to create an index for property keys that don\'t ' + 'exist in your current schema. Trying to make an index for the property ' + 'keys: ' + JSON.stringify(missingPropertyKeys));
};

/**
 * Schema abstraction over the Schema REST endpoint. Allows you to create and
 * retrieve a schema.
 *
 * @param {Object} params
 * @param {Object} params.auth - Auth object used to create the Session
 * @param {String} params.uri - URI string for the service
 * @returns {Object}
 */
var Schema = function () {
  var ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee3(_ref2) {
    var auth = _ref2.auth;
    var uri = _ref2.uri;
    var debug = _ref2.debug;

    var _ref3, query, schemaURI, get, schema, create;

    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return (0, _Session2.default)({ auth: auth, uri: uri, debug: debug });

          case 2:
            _ref3 = _context3.sent;
            query = _ref3.query;
            schemaURI = uri + '/schema';

            get = function () {
              var ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
                var _ref4, result;

                return regeneratorRuntime.wrap(function _callee$(_context) {
                  while (1) {
                    switch (_context.prev = _context.next) {
                      case 0:
                        _context.prev = 0;
                        _context.next = 3;
                        return query({
                          uri: schemaURI,
                          method: 'GET'
                        });

                      case 3:
                        _ref4 = _context.sent;
                        result = _ref4.result;
                        return _context.abrupt('return', result.data[0]);

                      case 8:
                        _context.prev = 8;
                        _context.t0 = _context['catch'](0);
                        return _context.abrupt('return', _context.t0);

                      case 11:
                      case 'end':
                        return _context.stop();
                    }
                  }
                }, _callee, undefined, [[0, 8]]);
              })),
                  _this = undefined;

              return function get() {
                return ref.apply(_this, arguments);
              };
            }();

            _context3.next = 8;
            return get();

          case 8:
            schema = _context3.sent;

            create = function () {
              var ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(schemaMutation) {
                var vertexIndexes, edgeIndexes, rest, _ref5, _result;

                return regeneratorRuntime.wrap(function _callee2$(_context2) {
                  while (1) {
                    switch (_context2.prev = _context2.next) {
                      case 0:
                        vertexIndexes = schemaMutation.vertexIndexes;
                        edgeIndexes = schemaMutation.edgeIndexes;
                        rest = _objectWithoutProperties(schemaMutation, ['vertexIndexes', 'edgeIndexes']);

                        checkForPropertyKey(schema, edgeIndexes);
                        checkForPropertyKey(schema, vertexIndexes);

                        _context2.prev = 5;
                        _context2.next = 8;
                        return query({
                          uri: schemaURI,
                          method: 'POST',
                          json: schemaMutation
                        });

                      case 8:
                        _ref5 = _context2.sent;
                        _result = _ref5.result;

                        schema = _result.data[0];

                        return _context2.abrupt('return', _result.data);

                      case 14:
                        _context2.prev = 14;
                        _context2.t0 = _context2['catch'](5);
                        return _context2.abrupt('return', _context2.t0);

                      case 17:
                      case 'end':
                        return _context2.stop();
                    }
                  }
                }, _callee2, undefined, [[5, 14]]);
              })),
                  _this = undefined;

              return function create(_x2) {
                return ref.apply(_this, arguments);
              };
            }();

            return _context3.abrupt('return', {
              get: get,
              create: create,
              schema: schema
            });

          case 11:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined);
  })),
      _this = undefined;

  return function Schema(_x) {
    return ref.apply(_this, arguments);
  };
}();

exports.default = Schema;