'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.dedupeStrategy = exports.dedupeByKey = exports.dedupeByName = undefined;

var _invariant = require('invariant');

var _invariant2 = _interopRequireDefault(_invariant);

var _areEqual = require('../utils/areEqual');

var _areEqual2 = _interopRequireDefault(_areEqual);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var dedupeByName = function dedupeByName(collection) {
  var cache = {};

  return collection.reduce(function (acc, item) {
    var name = item.name;

    if (cache[name]) {
      (0, _invariant2.default)((0, _areEqual2.default)(item, cache[name]), 'Mismatch occured between duplicate label entries. Expected %s, got %s', JSON.stringify(item, null, 2), JSON.stringify(cache[name], null, 2));

      return acc;
    }

    cache[name] = item;

    return acc.concat(item);
  }, []);
};

var dedupeByKey = function dedupeByKey(collection) {
  var keys = collection.reduce(function (acc, item) {
    var name = item.name;
    var propertyKeys = item.propertyKeys;

    if (acc[name]) {
      var _acc$name$propertyKey;

      (_acc$name$propertyKey = acc[name].propertyKeys).push.apply(_acc$name$propertyKey, _toConsumableArray(propertyKeys));

      return acc;
    }

    return _extends({}, acc, _defineProperty({}, name, item));
  }, {});

  return Object.keys(keys).map(function (key) {
    return keys[key];
  });
};

var dedupeStrategy = {
  edgeLabels: dedupeByName,
  edgeIndexes: dedupeByName,
  propertyKeys: dedupeByName,
  vertexLabels: dedupeByName,
  vertexIndexes: dedupeByKey
};

exports.dedupeByName = dedupeByName;
exports.dedupeByKey = dedupeByKey;
exports.dedupeStrategy = dedupeStrategy;