'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.flattenVertices = exports.flattenProperties = exports.flattenVertex = exports.flattenEdges = undefined;

var _invariant = require('invariant');

var _invariant2 = _interopRequireDefault(_invariant);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var checkIndex = function checkIndex(index) {
  if (!index) {
    return;
  }

  (0, _invariant2.default)(['name', 'unique', 'composite', 'indexOnly'].every(function (t) {
    return index.hasOwnProperty(t);
  }), 'An index requires `name`, `unique`, `composite`, and `indexOnly to be ' + 'specified. Instead got: ' + JSON.stringify(index, null, 2));

  var indexOnly = index.indexOnly;

  var rest = _objectWithoutProperties(index, ['indexOnly']);

  (0, _invariant2.default)(indexOnly === false || typeof indexOnly === 'string', '`indexOnly` should either be a label specified as a string or should ' + 'be set to `false`.');

  if (!indexOnly) {
    return rest;
  }

  return _extends({ indexOnly: indexOnly }, rest);
};

// Take in an Edge and return back the Label and any Index specified on it
var flattenEdge = function flattenEdge(edge) {
  var name = edge.name;
  var multiplicity = edge.multiplicity;
  var directed = edge.directed;

  (0, _invariant2.default)(['name', 'multiplicity', 'directed'].every(function (t) {
    return edge.hasOwnProperty(t);
  }), 'An edge requires `name`, `multiplicity`, and `directed` to be specified. ' + 'Instead got: ' + JSON.stringify(edge, null, 2));

  return [{ name: name, multiplicity: multiplicity, directed: directed }];
};

var flattenEdges = function flattenEdges(edges) {
  return edges.map(flattenEdge).reduce(function (acc, _ref) {
    var _ref2 = _slicedToArray(_ref, 1);

    var label = _ref2[0];
    return acc.concat(label);
  }, []);
};

var flattenProperty = function flattenProperty(property) {
  var name = property.name;
  var dataType = property.dataType;
  var cardinality = property.cardinality;
  var index = property.index;

  (0, _invariant2.default)(['name', 'dataType', 'cardinality'].every(function (t) {
    return property.hasOwnProperty(t);
  }), 'A property requires `name`, `dataType`, and `cardinality` to be ' + 'specified. Instead got: ' + JSON.stringify(property, null, 2));

  var validatedIndex = undefined;

  if (index) {
    validatedIndex = _extends({
      propertyKeys: [name]
    }, checkIndex(index));
  }

  return [{ name: name, dataType: dataType, cardinality: cardinality }, validatedIndex];
};

var flattenProperties = function flattenProperties(properties, indexType) {
  return properties.map(flattenProperty).reduce(function (acc, _ref3) {
    var _ref4 = _slicedToArray(_ref3, 2);

    var propertyKey = _ref4[0];
    var index = _ref4[1];
    var propertyKeys = acc.propertyKeys;
    var prevIndexType = acc[indexType];

    var nextIndex = index ? prevIndexType.concat(index) : prevIndexType;

    return _defineProperty({
      propertyKeys: propertyKeys.concat(propertyKey)
    }, indexType, nextIndex);
  }, _defineProperty({
    propertyKeys: []
  }, indexType, []));
};

var flattenVertex = function flattenVertex(vertex) {
  var name = vertex.name;
  var vertexProperties = vertex.properties;
  var inEdges = vertex.inEdges;
  var outEdges = vertex.outEdges;

  var allEdges = [].concat(_toConsumableArray(inEdges), _toConsumableArray(outEdges));

  var edgeProperties = allEdges.filter(function (e) {
    return e.properties;
  }).map(function (e) {
    return e.properties;
  }).reduce(function (acc, p) {
    return acc.concat(p);
  }, []);

  var properties = _extends({}, flattenProperties(edgeProperties, 'edgeIndexes'), flattenProperties(vertexProperties, 'vertexIndexes'));

  var edges = flattenEdges(allEdges);

  return _extends({
    vertexLabels: [{ name: name }],
    edgeLabels: edges
  }, properties);
};

var flattenVertices = function flattenVertices(vertices) {
  return vertices.map(flattenVertex).reduce(function (acc, vertex) {
    return {
      edgeLabels: acc.edgeLabels.concat(vertex.edgeLabels),
      edgeIndexes: acc.edgeIndexes.concat(vertex.edgeIndexes),
      propertyKeys: acc.propertyKeys.concat(vertex.propertyKeys),
      vertexIndexes: acc.vertexIndexes.concat(vertex.vertexIndexes),
      vertexLabels: acc.vertexLabels.concat(vertex.vertexLabels)
    };
  }, {
    edgeIndexes: [],
    edgeLabels: [],
    propertyKeys: [],
    vertexIndexes: [],
    vertexLabels: []
  });
};

exports.flattenEdges = flattenEdges;
exports.flattenVertex = flattenVertex;
exports.flattenProperties = flattenProperties;
exports.flattenVertices = flattenVertices;